# Show running .NET-Version
# Stop-Process -Name notepad -Force -ErrorAction SilentlyContinue
$execruntime = [System.Reflection.Assembly]::GetExecutingAssembly().ImageRuntimeVersion
#
$ExportPath = $env:TEMP
$ExportFile = "software-info-$env:Username@$env:computername"
Remove-Item $ExportPath\$ExportFile -Force -ErrorAction SilentlyContinue
#

# ---- Ausgabe --- START ------ 
$DateTXT = Get-Date -format "dd.MM.yyyy - HH:mm:ss tt"
Write-Output "------------------------------------------------------------------" | Out-File "$ExportPath\$ExportFile" -Encoding utf8
Write-Output "Software-Info Tool - Ver. 1.2.12 (13.05.2024) / .NET Runtime $execruntime" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
Write-Output "Download https:\\www.hekret.de\pcinfo" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
Write-Output "------------------------------------------------------------------`r`n" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
# Write-Output "`n" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
Write-Output "Erstellt von Benutzer '$env:userdomain\$env:USERNAME'`r`n" | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
Write-Output "Datensatz erstellt am $DateTXT`r`n" | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
#

Write-Host "------------------------------------------------------------------"
Write-Host "Software-Info Tool - Ver. 1.2.12 (13.05.2024) / .NET Runtime $execruntime"
Write-Host "Download https:\\www.hekret.de\pcinfo"
Write-Host "------------------------------------------------------------------`r`n"

# --- Info Machine / User --- START ---
$machinename = (Get-CimInstance -Class:Win32_Computersystem).Name
$domain = (Get-CimInstance Win32_ComputerSystem).Domain

# ActiveDirectory Site abfragen und Fehler abfangen.
try {
    $adsite = [System.DirectoryServices.ActiveDirectory.ActiveDirectorySite]::GetComputerSite().Name
    }
    catch
    {
    # Write-Host $PSItem.Exception.Message
    Set-Variable -Name adsite -Value "-"
    }
#
#
$dr = Get-CimInstance -Class win32_computersystem | Select-Object -ExpandProperty domainrole
$domainrole = switch ($dr) {
    0 {"Standalone Workstation"} 
    1 {"Member Workstation"} 
    2 {"Standalone Server"} 
    3 {"Member Server"} 
    4 {"Backup Domain Controller"} 
    5 {"Primary Domain Controller"} 
    default {"Unknown"} 
    } # end switch



write-Output "
Domain Machine Info:`
    Computername: ............... $machinename`
    ActiveDirectory: ............ $domain`
    Site: ....................... $adsite`
    Domain Role: ................ $domainrole`
`
Domain User Info:`
    ActiveDirectory: ............ $env:userdomain`
    LogonServer: ................ $env:logonserver`
    UserName: ................... $env:USERNAME`
    `
    `
    " | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append

# --- Info Machine / User --- END ---

# Write-Host "Status:`n"
Write-Host "collecting Data ...  / sammle Daten ...`r`n"
#
# "------- license status (Win / Office / other MS) / Lizenzstatus (Win / Office / other MS) --- Start -------------------------------------------------------------------"
Write-Host "license status (Win / Office / other MS) / Lizenzstatus (Win / Office / other MS)`n"
Write-Output "------- license status (Win / Office / other MS) / Lizenzstatus (Win / Office / other MS) ------- START ----" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
#
$LicenseStatus = @{
    Name = 'LicenseStatus'
    Expression = {
      # property is an array, so process all values
      $value = $_.LicenseStatus
      
      switch([int]$value)
        {
          0          {'Unlicensed'}
          1          {'Licensed'}
          2          {'OOBGrace = Out-of-Box Grace'}
          3          {'OOTGrace = Out of Tolerance Grace'}
          4          {'NonGenuineGrace'}
          5          {'Notification'}
          6          {'ExtendedGrace'}
          default    {"$value"}
        }
    }  
  }

# Fast - 5 Sek
Get-CimInstance SoftwareLicensingProduct -Filter 'ProductKeyId != NULL' | Where-Object { $_.PartialProductKey } | `
Select-Object Description, $LicenseStatus, LicenseFamily, Name, PartialProductKey, ProductKeyChannel  | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append

#
Write-Host "------------------------------------------------------------------`r`n"
write-Output "`n`n" | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
# Write-Output "--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--`r`n" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
Write-Host "Software + Apps (Userprofile / 64-Bit / 32-Bit)`n"
# Get-CimInstance -Class Win32_Product | Select-Object -Property Name,Version,Vendor,IdentifyingNumber | Format-Table -AutoSize)
#
# Software-List UserProfile
Write-Host "-- Windows - Software-List (UserProfile) --"
Write-Output "------- Windows - Software-List (UserProfile) ------- START ----`n" | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
Get-ItemProperty HKCU:\Software\Microsoft\Windows\CurrentVersion\Uninstall\* | Where-Object { ($_.DisplayName -gt "0" ) } | `
	Select-Object DisplayName, DisplayVersion, Publisher, InstallDate | Sort-Object -Property DisplayName | Format-Table -AutoSize -Wrap | `
	Out-File -Width 500 -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
#
write-Output "`n`n" | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
#
# 64 Software-List @ 64-Bit Windows
# 32 Software-List @ 32-Bit Windows 
Write-Host "-- Windows Native - 64-bit - Software-List (Machine) --"
write-Output "------- Windows Native - 64-bit - Software-List (Machine) ------- START ----`n" | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
Get-ItemProperty HKLM:\Software\Microsoft\Windows\CurrentVersion\Uninstall\* | Where-Object { ($_.DisplayName -gt "0" ) } | `
	Select-Object DisplayName, DisplayVersion, Publisher, InstallDate | Sort-Object -Property DisplayName | Format-Table -AutoSize -Wrap | `
	Out-File -Width 500 -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
#
write-Output "`n`n" | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
# 32-Bit Software-List @ 64-Bit Windows
#
Write-Host "-- Windows - 32-Bit - Software-List (Machine) --"
Write-Output "------- Windows - 32-Bit - Software-List (Machine) ------- START ----`n" | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
Get-ItemProperty HKLM:\SOFTWARE\Wow6432Node\Microsoft\Windows\CurrentVersion\Uninstall\* | Where-Object { ($_.DisplayName -gt "0" ) } | `
	Select-Object DisplayName, DisplayVersion, Publisher, InstallDate | Sort-Object -Property DisplayName | Format-Table -AutoSize -Wrap | `
	Out-File -Width 500 -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
#
Write-Host "------------------------------------------------------------------`r`n"
write-Output "`n`n" | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
# Write-Output "--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--`r`n" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
#
# ------------------- Software List ---------------- END -------------------
#
# "------- Apps-List UserProfile (without/ohne FrameWorks, NonRemovable-Apps) --- Start -------------------------------------------------------------------"
Write-Host "Apps-List UserProfile (without/ohne FrameWorks, NonRemovable-Apps)`n"
Write-Output "------- Apps-List UserProfile (without/ohne FrameWorks, NonRemovable-Apps) ------- START ----" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
#
# Apps-List UserProfile (without/ohne FrameWorks, NonRemovable-Apps)
Get-AppxPackage -User $env:username | `
    Where-Object  -FilterScript { ($PSItem.NonRemovable -eq $False) -and  ($PSItem.IsFramework -eq $False)  } | `
#    Select-Object Name,Architecture,Version,PackageFullName,PackageFamilyName,Publisher,PublisherId,InstallLocation | `
    Select-Object Name,Architecture,Version,NonRemovable,PublisherId,InstallLocation | `
    Sort-Object -Property Name | Format-Table -AutoSize -Wrap | `
    Out-File -Width 500 -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
	
#
Write-Host "------------------------------------------------------------------`r`n"
write-Output "`n`n" | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
# Write-Output "--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--`r`n" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
# "------- Framewwork Apps  --- Start -------------------------------------------------------------------"
Write-Host "Framewwork Apps `n"
Write-Output "------- Framewwork Apps ------- START ----" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
#
# FrameWork Apps
Get-AppxPackage | `
	Where-Object  -FilterScript { ($PSItem.IsFramework -eq $True) } | `
#	Select-Object Name,Architecture,Version,NonRemovable,PackageFullName,PackageFamilyName,Publisher,PublisherId | `
	Select-Object Name,Architecture,Version,NonRemovable,PublisherId,InstallLocation | `
	Sort-Object -Property Name | Sort-Object -Property Name | Format-Table -AutoSize -Wrap  | `
	Out-File -Width 500 -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append

#
Write-Host "------------------------------------------------------------------`r`n"
write-Output "`n`n" | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
Write-Output "--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--`r`n" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append

# ---- Ausgabe --- END ------ 
#
$DateTXT = Get-Date -format "dd.MM.yyyy - HH:mm:ss tt"
Write-Output "------------------------------------------------------------------" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
Write-Output "Erfassung abgeschlossen: $DateTXT" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
Write-Output "------------------------------------------------------------------`r`n" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
Write-Output "_______________ - End of File - ______________________`r`n" | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
#
# Get-Content $ExportPath\$ExportFile
# pause
Start-Process notepad.exe $ExportPath\$ExportFile
